@@ -1,6 +1,6 @@
 package Hubot::Scripts::Bundle;
 {
-  $Hubot::Scripts::Bundle::VERSION = '0.0.2';
+  $Hubot::Scripts::Bundle::VERSION = '0.0.3';
 }
 
 1;
@@ -21,7 +21,8 @@ example F<hubot-scripts.json>
         "redisBrain",
         "help",
         "ping",
-        "uptime"
+        "uptime",
+        "whisper"
     ]
 
 and then,
@@ -57,6 +58,14 @@ using redis as an external storage for robot's brain
     me> hubot: uptime
     hubot> I've been sentient for 0 years, 00 months, 2 days, 00 hours, 252 minutes, 07 seconds
 
+=item whisper
+
+    # IRC only
+    me> /msg hubot <channel> <text>
+    hubot> <text>
+
+speak <text> behind hubot
+
 =back
 
 =head1 SEE ALSO
